#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-docs
version:              1.0.12
visibility:           public
id:                   dhall-docs-1.0.12-8NhoxCSTIBF9F2GgCzB9yw
key:                  dhall-docs-1.0.12-8NhoxCSTIBF9F2GgCzB9yw
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  9e06d6e9551fbecd7f6b723bf127cde3
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.12-8NhoxCSTIBF9F2GgCzB9yw
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-JUk8AN14DnGL6jo9gy2A1N
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-2nt93OmkYH2AU8wUadhI32
    dhall-1.42.3-DySaYwwbIGfLXU3muHnRTK directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    lucid-2.11.20260427-JjJUhnUt6qGKNKxSk9iUzh
    megaparsec-9.7.1-3v9USGunK8PJV50Lxdl0PB
    mmark-0.0.8.0-Lc8vMXOGgdpDxHPeNSA2JU mtl-2.3.1
    optparse-applicative-0.18.1.0-47hFtTaenhPJTeGKwQSLW6
    path-0.9.6-BxhS1zhBGPXAv36OYtgfyJ
    path-io-1.8.2-FuZ8g3n9DutKRzBsYyarXM
    prettyprinter-1.7.2-1DGqCnBpxP9HlPCcGuqpc1 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

